#
# spec file for package xcmsdb
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           xcmsdb
Version:        1.0.7
Release:        1.3
Summary:        Device Color Characterization utility for X Color Management System
License:        MIT
Group:          System/X11/Utilities
URL:            http://xorg.freedesktop.org/
Source0:        http://xorg.freedesktop.org/releases/individual/app/%{name}-%{version}.tar.xz
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xorg-macros) >= 1.8
# This was part of the xorg-x11 package up to version 7.6
Conflicts:      xorg-x11 <= 7.6
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
xcmsdb is used to load, query, or remove Device Color Characterization
data stored in properties on the root window of the screen as
specified in section 7, Device Color Characterization, of the
X11 Inter-Client Communication Conventions Manual (ICCCM).

%prep
%setup -q

%build
%configure
make %{?_smp_mflags}

%install
%make_install

%files
%defattr(-,root,root)
%doc ChangeLog COPYING README.md
%{_bindir}/xcmsdb
%{_mandir}/man1/xcmsdb.1%{?ext_man}

%changelog
* Sun Oct 13 2024 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.0.7
  * This release fixes some compiler warnings and includes other
    minor code cleanups.
* Mon Jul 11 2022 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.0.6
  * Update README for gitlab migration
  * Update configure.ac bug URL for gitlab migration
  * Fix spelling/wording issues
  * gitlab CI: add a basic build test
  * Build xz tarballs instead of bzip2
  * Fix -Wsign-compare warnings in PrintTableType1()
  * Adopt X.Org standard coding style
  * Remove unnecessary casts and make allocation failure checks more
    consistent
  * LoadSCCData: avoid leaking memory if we give up early
  * autogen.sh: use quoted string variables
  * autogen: add default patch prefix
  * autogen.sh: use exec instead of waiting for configure to finish
* Fri Apr 24 2015 sndirsch@suse.com
- Update to version 1.0.5:
  * Combine usage message strings
  * Print which option was in error along with usage message
  * Add -version option to print program version
  * Fix const char * warnings
  * Remove break statements immediately after return statements
  * config: Add missing AC_CONFIG_SRCDIR
  * configure: Drop AM_MAINTAINER_MODE
  * autogen.sh: Honor NOCONFIGURE=1
  * Strip trailing whitespace from source files
  * Only use results from GetWindowProperty if it returned Success
  * _XcmsGetProperty: don't deal with uninitialized values, fail instead
* Sun Apr 15 2012 dimstar@opensuse.org
- Update to version 1.0.4:
  + Improved error handling for corrupt intensity profiles
  + Coding style cleanup to appease static analyzer
  + Build system fixes.
* Fri Apr 13 2012 vuntz@opensuse.org
- Split xcmsdb from xorg-x11. Initial version: 1.0.3.
